==> haskell-warp-tls-3.4.9-179-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-JabKr8s8Ckk5DL2oD6FCdN
key:                  warp-tls-3.4.9-JabKr8s8Ckk5DL2oD6FCdN
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  91205d1f3b50af18cdb4d006aaf1c3ab
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-JabKr8s8Ckk5DL2oD6FCdN
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    recv-0.1.1-FYzLFraRQnxDWsE7fLZoUg
    streaming-commons-0.2.3.0-E1A8MXIidsEIETQNDtfU1f
    tls-2.0.6-HHKVvNcSfLyJGme2UrIiax
    tls-session-manager-0.0.6-H1eqJvq9mCy9YghTvTS0GV
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj warp-3.4.0-EqimZsrxjZl395Jtpn7CJI

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.4.9-180-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-BuMIif3ehnY6CP8dJbLHFg
key:                  warp-tls-3.4.9-BuMIif3ehnY6CP8dJbLHFg
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  c9d3c3365f56e711fb8fe9166c34add9
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-BuMIif3ehnY6CP8dJbLHFg
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    recv-0.1.1-FYzLFraRQnxDWsE7fLZoUg
    streaming-commons-0.2.3.1-JQd7Uft3nuo1D7ll7sM2yO
    tls-2.0.6-HHKVvNcSfLyJGme2UrIiax
    tls-session-manager-0.0.6-H1eqJvq9mCy9YghTvTS0GV
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj warp-3.4.0-HpC7vpiyF2eriPYOziTRJ

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
